@@ -42,7 +42,11 @@ class DBBase:
         return not self.is_open
 
     def log(
-        self, sql: str, params: Optional[Params], duration: float, error: bool
+        self,
+        sql: str,
+        params: Optional[Params],
+        duration: float,
+        error: Optional[Exception],
     ) -> None:
         """Hook for logging out sql, params, along with duration and error information.
         Override to do something with this information.
@@ -118,15 +122,15 @@ class DBBase:
 
         await self.auto_open()
         start = time()
-        error = False
+        error: Optional[Exception] = None
 
         try:
             if params:
                 await self.conn.execute(sql, *params)
             else:
                 await self.conn.execute(sql)
-        except:
-            error = True
+        except Exception as ex:
+            error = ex
             raise
         finally:
             self.log(sql, params, time() - start, error)
@@ -144,15 +148,15 @@ class DBBase:
 
         await self.auto_open()
         start = time()
-        error = False
+        error: Optional[Exception] = None
 
         try:
             if params:
                 await self.conn.executemany(sql, params)
             else:
                 await self.conn.executemany(sql)
-        except:
-            error = True
+        except Exception as ex:
+            error = ex
             raise
         finally:
             self.log(sql, params, time() - start, error)
@@ -170,15 +174,15 @@ class DBBase:
 
         await self.auto_open()
         start = time()
-        error = False
+        error: Optional[Exception] = None
 
         try:
             if params:
                 return await self.conn.fetch(sql, *params)
 
             return await self.conn.fetch(sql)
-        except:
-            error = True
+        except Exception as ex:
+            error = ex
             raise
         finally:
             self.log(sql, params, time() - start, error)
@@ -196,15 +200,15 @@ class DBBase:
 
         await self.auto_open()
         start = time()
-        error = False
+        error: Optional[Exception] = None
 
         try:
             if params:
                 return await self.conn.fetchrow(sql, *params)
 
             return await self.conn.fetchrow(sql)
-        except:
-            error = True
+        except Exception as ex:
+            error = ex
             raise
         finally:
             self.log(sql, params, time() - start, error)
